zlib_portmonitor {#master}
------------------

### PortMonitors

* added new portmonitor `depthimage_compression_zlib` which uses zlib library to compress/decompress (lossless) depth images through the network